Module process

Module process 

Available on crate feature async-client only.
Finding, launching, and handshaking with the localharness binary.

Structs

Harness
A running localharness process that has completed its stdio handshake.
HarnessOptions
How to launch and configure a harness session.
ModelBuilder
A model endpoint for HarnessOptions::model.

Constants

HARNESS_PATH_ENV
The environment variable the reference client checks first, and so do we.

Functions

find_harness
Locates the localharness binary.