pub struct McpServerConfig {
pub stdio: Option<McpStdioTransport>,
pub http: Option<McpHttpTransport>,
pub name: Option<String>,
pub enabled_tools: Vec<String>,
pub disabled_tools: Vec<String>,
pub auth_provider_type: Option<McpServerConfigAuthProviderType>,
pub timeout_seconds: Option<i32>,
}Expand description
antigravity.localharness.McpServerConfig
Fields
stdio: Option<McpStdioTransport>http: Option<McpHttpTransport>name: Option<String>enabled_tools: Vec<String>disabled_tools: Vec<String>auth_provider_type: Option<McpServerConfigAuthProviderType>timeout_seconds: Option<i32>Implementations
Sourceimpl McpServerConfig
impl McpServerConfig
Sourcepub fn into_transport(self) -> Option<McpServerConfigTransport>
pub fn into_transport(self) -> Option<McpServerConfigTransport>
Takes the set arm of the transport oneof, if any.
Sourcepub fn has_transport(&self) -> bool
pub fn has_transport(&self) -> bool
True when any arm of the transport oneof is set.