pub struct ModelConfig {
pub gemini_api_endpoint: Option<GeminiAPIEndpoint>,
pub vertex_endpoint: Option<VertexEndpoint>,
pub gemma_endpoint: Option<GemmaEndpoint>,
pub custom_endpoint: Option<CustomEndpoint>,
pub name: Option<String>,
pub types: Vec<ModelType>,
}Expand description
antigravity.localharness.ModelConfig
Fields
gemini_api_endpoint: Option<GeminiAPIEndpoint>vertex_endpoint: Option<VertexEndpoint>gemma_endpoint: Option<GemmaEndpoint>custom_endpoint: Option<CustomEndpoint>name: Option<String>types: Vec<ModelType>Implementations
Sourceimpl ModelConfig
impl ModelConfig
Sourcepub fn into_endpoint(self) -> Option<ModelConfigEndpoint>
pub fn into_endpoint(self) -> Option<ModelConfigEndpoint>
Takes the set arm of the endpoint oneof, if any.
Sourcepub fn has_endpoint(&self) -> bool
pub fn has_endpoint(&self) -> bool
True when any arm of the endpoint oneof is set.