OutputEvent

Struct OutputEvent 

pub struct OutputEvent {
    pub step_update: Option<StepUpdate>,
    pub trajectory_state_update: Option<TrajectoryStateUpdate>,
    pub tool_call: Option<ToolCall>,
    pub initialize_conversation_response: Option<InitializeConversationResponse>,
    pub call_hook_request: Option<CallHookRequest>,
    pub session_end_response: Option<bool>,
    pub policy_decision_request: Option<PolicyDecisionRequest>,
    pub usage_update: Option<UsageUpdate>,
    pub seq_num: Option<i64>,
    pub timestamp_micros: Option<i64>,
}
antigravity.localharness.OutputEvent

Fields

step_update: Option<StepUpdate>trajectory_state_update: Option<TrajectoryStateUpdate>tool_call: Option<ToolCall>initialize_conversation_response: Option<InitializeConversationResponse>call_hook_request: Option<CallHookRequest>session_end_response: Option<bool>policy_decision_request: Option<PolicyDecisionRequest>usage_update: Option<UsageUpdate>seq_num: Option<i64>timestamp_micros: Option<i64>

Implementations

Source

impl OutputEvent

pub fn sequence(&self) -> Option<i64>

The monotonically increasing sequence number the harness stamps on every frame, useful for ordering assertions and gap detection.

Source

impl OutputEvent

pub fn into_event(self) -> Option<OutputEventEvent>

Takes the set arm of the event oneof, if any.

pub fn has_event(&self) -> bool

True when any arm of the event oneof is set.