StepUpdate

Struct StepUpdate 

pub struct StepUpdate {
Show 30 fields pub cascade_id: Option<String>, pub trajectory_id: Option<String>, pub step_index: Option<u32>, pub state: Option<StepUpdateState>, pub source: Option<StepUpdateSource>, pub target: Option<StepUpdateTarget>, pub error_message: Option<String>, pub thinking: Option<String>, pub text_delta: Option<String>, pub thinking_delta: Option<String>, pub text: Option<String>, pub list_directory: Option<ActionListDirectory>, pub find_file: Option<ActionFindFile>, pub search_directory: Option<ActionSearchDirectory>, pub view_file: Option<ActionViewFile>, pub create_file: Option<ActionCreateFile>, pub edit_file: Option<ActionEditFile>, pub run_command: Option<ActionRunCommand>, pub compaction: Option<ActionCompaction>, pub invoke_subagent: Option<ActionInvokeSubagent>, pub generate_image: Option<ActionGenerateImage>, pub finish: Option<ActionFinish>, pub error: Option<ActionError>, pub mcp_tool: Option<ActionMcpTool>, pub search_web: Option<ActionSearchWeb>, pub read_url_content: Option<ActionReadUrlContent>, pub custom_tool: Option<ActionCustomTool>, pub request_text: Option<String>, pub tool_confirmation_request: Option<ToolConfirmationRequest>, pub questions_request: Option<UserQuestionsRequest>,
}
antigravity.localharness.StepUpdate

Fields

cascade_id: Option<String>trajectory_id: Option<String>step_index: Option<u32>state: Option<StepUpdateState>source: Option<StepUpdateSource>target: Option<StepUpdateTarget>error_message: Option<String>thinking: Option<String>text_delta: Option<String>thinking_delta: Option<String>text: Option<String>list_directory: Option<ActionListDirectory>find_file: Option<ActionFindFile>search_directory: Option<ActionSearchDirectory>view_file: Option<ActionViewFile>create_file: Option<ActionCreateFile>edit_file: Option<ActionEditFile>run_command: Option<ActionRunCommand>compaction: Option<ActionCompaction>invoke_subagent: Option<ActionInvokeSubagent>generate_image: Option<ActionGenerateImage>finish: Option<ActionFinish>error: Option<ActionError>mcp_tool: Option<ActionMcpTool>search_web: Option<ActionSearchWeb>read_url_content: Option<ActionReadUrlContent>custom_tool: Option<ActionCustomTool>request_text: Option<String>tool_confirmation_request: Option<ToolConfirmationRequest>questions_request: Option<UserQuestionsRequest>

Implementations

Source

impl StepUpdate

pub fn is_terminal(&self) -> bool

True once this step will not be updated again.

pub fn text_or_delta(&self) -> Option<&str>

The text this step contributes, preferring the accumulated text the harness sends on completion over the incremental delta.