pub struct ToolOutputTruncation {
pub truncate: Option<ToolOutputTruncationTruncateStrategy>,
pub error: Option<ToolOutputTruncationErrorStrategy>,
}Expand description
antigravity.localharness.ToolOutputTruncation
Fields
truncate: Option<ToolOutputTruncationTruncateStrategy>error: Option<ToolOutputTruncationErrorStrategy>Implementations
Sourceimpl ToolOutputTruncation
impl ToolOutputTruncation
Sourcepub fn into_strategy(self) -> Option<ToolOutputTruncationStrategy>
pub fn into_strategy(self) -> Option<ToolOutputTruncationStrategy>
Takes the set arm of the strategy oneof, if any.
Sourcepub fn has_strategy(&self) -> bool
pub fn has_strategy(&self) -> bool
True when any arm of the strategy oneof is set.